==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OcenaKryteriumKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class OcenaKryteriumKey extends GenericDPSObject {
    /**
     * OCENA_KRYTERIUM.OCENA_OSOBA_SKALA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ocenaOsobaSkalaId;

    /**
     * OCENA_KRYTERIUM.KRYTERIUM_OPCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kryteriumOpcjaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OCENA_KRYTERIUM.OCENA_OSOBA_SKALA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOcenaOsobaSkalaId() {
        return ocenaOsobaSkalaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * OCENA_KRYTERIUM.OCENA_OSOBA_SKALA_ID
     *
     * @param ocenaOsobaSkalaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOcenaOsobaSkalaId(Long ocenaOsobaSkalaId) {
        this.ocenaOsobaSkalaId = ocenaOsobaSkalaId;
    }

    /**
     * @return OCENA_KRYTERIUM.KRYTERIUM_OPCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKryteriumOpcjaId() {
        return kryteriumOpcjaId;
    }

    /**
     * OCENA_KRYTERIUM.KRYTERIUM_OPCJA_ID
     *
     * @param kryteriumOpcjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKryteriumOpcjaId(Long kryteriumOpcjaId) {
        this.kryteriumOpcjaId = kryteriumOpcjaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OcenaKryteriumKey other = (OcenaKryteriumKey) that;
        return (this.getOcenaOsobaSkalaId() == null ? other.getOcenaOsobaSkalaId() == null : this.getOcenaOsobaSkalaId().equals(other.getOcenaOsobaSkalaId()))
            && (this.getKryteriumOpcjaId() == null ? other.getKryteriumOpcjaId() == null : this.getKryteriumOpcjaId().equals(other.getKryteriumOpcjaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getOcenaOsobaSkalaId() == null) ? 0 : getOcenaOsobaSkalaId().hashCode());
        result = prime * result + ((getKryteriumOpcjaId() == null) ? 0 : getKryteriumOpcjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", ocenaOsobaSkalaId=").append(ocenaOsobaSkalaId);
        sb.append(", kryteriumOpcjaId=").append(kryteriumOpcjaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OcenaKryteriumKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class OcenaKryteriumKey extends GenericDPSObject {
    /**
     * OCENA_KRYTERIUM.OCENA_OSOBA_SKALA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ocenaOsobaSkalaId;

    /**
     * OCENA_KRYTERIUM.KRYTERIUM_OPCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kryteriumOpcjaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OCENA_KRYTERIUM.OCENA_OSOBA_SKALA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOcenaOsobaSkalaId() {
        return ocenaOsobaSkalaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:46
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * OCENA_KRYTERIUM.OCENA_OSOBA_SKALA_ID
     *
     * @param ocenaOsobaSkalaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOcenaOsobaSkalaId(Long ocenaOsobaSkalaId) {
        this.ocenaOsobaSkalaId = ocenaOsobaSkalaId;
    }

    /**
     * @return OCENA_KRYTERIUM.KRYTERIUM_OPCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKryteriumOpcjaId() {
        return kryteriumOpcjaId;
    }

    /**
     * OCENA_KRYTERIUM.KRYTERIUM_OPCJA_ID
     *
     * @param kryteriumOpcjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKryteriumOpcjaId(Long kryteriumOpcjaId) {
        this.kryteriumOpcjaId = kryteriumOpcjaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OcenaKryteriumKey other = (OcenaKryteriumKey) that;
        return (this.getOcenaOsobaSkalaId() == null ? other.getOcenaOsobaSkalaId() == null : this.getOcenaOsobaSkalaId().equals(other.getOcenaOsobaSkalaId()))
            && (this.getKryteriumOpcjaId() == null ? other.getKryteriumOpcjaId() == null : this.getKryteriumOpcjaId().equals(other.getKryteriumOpcjaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getOcenaOsobaSkalaId() == null) ? 0 : getOcenaOsobaSkalaId().hashCode());
        result = prime * result + ((getKryteriumOpcjaId() == null) ? 0 : getKryteriumOpcjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", ocenaOsobaSkalaId=").append(ocenaOsobaSkalaId);
        sb.append(", kryteriumOpcjaId=").append(kryteriumOpcjaId);
        sb.append("]");
        return sb.toString();
    }
}
